<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core
 */

/*
    This script is used by the homesite's install statistics service. It simply tells the homesite if a website is
    installed here based on the presence of _config.php and sources/bootstrap.php. Since htaccess blocks _config.php,
    we must use an API like this to determine an installation.

    The homesite will only query if you elected to provide statistics.
    And if this file no longer exists or reports the software is not installed, the homesite will stop querying
    for this file after a year.

    If you want your site to be immediately removed and the homesite to stop checking you, uncomment the echo line
    'Remove me!'. When the homesite sees this, it will immediately remove you from its install statistics service.
 */

header('X-Robots-Tag: noindex');
header('Content-Type: text/plain; charset=utf-8');
@header_remove('x-powered-by'); // Security

// Find base directory
global $FILE_BASE, $RELATIVE_PATH;
$FILE_BASE = (strpos(__FILE__, './') === false) ? __FILE__ : realpath(__FILE__);
$FILE_BASE = dirname($FILE_BASE);
if (!is_file($FILE_BASE . '/sources/bootstrap.php')) {
    $RELATIVE_PATH = basename($FILE_BASE);
    $FILE_BASE = dirname($FILE_BASE);
} else {
    $RELATIVE_PATH = '';
}
if (!is_file($FILE_BASE . '/sources/bootstrap.php')) {
    $FILE_BASE = $_SERVER['SCRIPT_FILENAME']; // this is with symlinks-unresolved (__FILE__ has them resolved); we need as we may want to allow zones to be symlinked into the base directory without getting path-resolved
    $FILE_BASE = dirname($FILE_BASE);
    if (!is_file($FILE_BASE . '/sources/bootstrap.php')) {
        $RELATIVE_PATH = basename($FILE_BASE);
        $FILE_BASE = dirname($FILE_BASE);
    } else {
        $RELATIVE_PATH = '';
    }
}

/*
    Un-comment these two lines and save the file if you want the homesite to stop checking if you have Composr installed and to remove all your
    data from its telemetry service. Before doing this, make sure you have the "Telemetry (what to relay to core developers)" option set to
    "Relay nothing" (Admin Zone > Setup > Configuration > Privacy / legal compliance options), otherwise your site will re-register itself
    with the telemetry service.

    Leave the lines in place for at least a few days to give the homesite a chance to see it (the homesite only checks on a daily interval).
*/

// echo 'Remove me!';
// exit();

/*
    Don't load in the software API because we don't want DOS attacks.
    We just need to check for two files. If they both exist, there's a 98% chance the software is indeed installed. Good enough to say yes for us.
*/
if (is_file($FILE_BASE . '/_config.php') && is_file($FILE_BASE . '/sources/bootstrap.php')) {
    if (is_file($FILE_BASE . '/data_custom/telemetry_challenge.txt')) { // Challenge to verify site ownership with telemetry
        echo file_get_contents($FILE_BASE . '/data_custom/telemetry_challenge.txt');
        @unlink($FILE_BASE . '/data_custom/telemetry_challenge.txt');
    } else {
        echo 'Yes';
    }
} else {
    echo 'No';
}
