<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    cns_member_photos
 */

/**
 * Hook class.
 */
class Hook_addon_registry_cns_member_photos
{
    /**
     * Get a list of file permissions to set.
     *
     * @param  boolean $runtime Whether to include wildcards represented runtime-created chmoddable files
     * @return array File permissions to set
     */
    public function get_chmod_array(bool $runtime = false) : array
    {
        $chmod = [];
        if ($runtime) {
            $chmod = array_merge(
                $chmod,
                [
                    'uploads/cns_photos/*',
                ]
            );
        }
        $chmod = array_merge(
            $chmod,
            [
                'uploads/cns_photos',
            ]
        );
        return $chmod;
    }

    /**
     * Get the current version of this addon (usually software major, software minor, addon build).
     * Put the comment "// addon_version_auto_update" to the right of the return if you want release tools to automatically update this according to software version and find_addon_effective_md5.
     *
     * @return SHORT_TEXT Version number
     */
    public function get_version() : string
    {
        return '11'; // addon_version_auto_update fd1d8130659fe811ae3ef9c3895ad355
    }

    /**
     * Get the minimum required version of the website software needed to use this addon.
     *
     * @return float Minimum required website software version
     */
    public function get_min_cms_version() : float
    {
        return 11.0;
    }

    /**
     * Get the maximum compatible version of the website software to use this addon.
     *
     * @return ?float Maximum compatible website software version (null: no maximum version currently)
     */
    public function get_max_cms_version() : ?float
    {
        return 11.9;
    }

    /**
     * Get the addon category.
     *
     * @return string The category
     */
    public function get_category() : string
    {
        return 'Community';
    }

    /**
     * Get the description of the addon.
     *
     * @return string Description of the addon
     */
    public function get_description() : string
    {
        return "Enable the ability for members to upload their own photos to be display on their profile page. These are larger photos than avatars but are less prominent as they only show up on a member's profile page.";
    }

    /**
     * Get a list of tutorials that apply to this addon.
     *
     * @return array List of tutorials
     */
    public function get_applicable_tutorials() : array
    {
        return [
            'tut_members',
        ];
    }

    /**
     * Get a mapping of dependency types.
     *
     * @return array A structure specifying dependency information
     */
    public function get_dependencies() : array
    {
        return [
            'requires' => [],
            'recommends' => [],
            'conflicts_with' => [],
        ];
    }

    /**
     * Explicitly say which icon should be used.
     *
     * @return URLPATH Icon
     */
    public function get_default_icon() : string
    {
        return 'themes/default/images/icons/tabs/member_account/edit/photo.svg';
    }

    /**
     * Get a list of files that belong to this addon.
     *
     * @return array List of files
     */
    public function get_file_list() : array
    {
        return [
            'sources/hooks/systems/addon_registry/cns_member_photos.php',
            'sources/hooks/systems/profiles_tabs_edit/photo.php',
            'themes/default/images/icons/tabs/member_account/edit/photo.svg',
            'themes/default/images/icons_monochrome/tabs/member_account/edit/photo.svg',
            'themes/default/templates/CNS_EDIT_PHOTO_TAB.tpl',
            'uploads/cns_photos/.htaccess',
            'uploads/cns_photos/index.html',
            'uploads/cns_photos_thumbs/.htaccess',
            'uploads/cns_photos_thumbs/index.html',
        ];
    }

    /**
     * Get mapping between template names and the method of this class that can render a preview of them.
     *
     * @return array The mapping
     */
    public function tpl_previews() : array
    {
        return [
            'templates/CNS_EDIT_PHOTO_TAB.tpl' => 'cns_edit_photo_tab',
        ];
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__cns_edit_photo_tab() : object
    {
        require_lang('cns');
        require_css('cns');

        return lorem_globalise(do_lorem_template('CNS_EDIT_PHOTO_TAB', [
            'USERNAME' => lorem_word(),
            'PHOTO' => placeholder_image_url(),
            'TEXT' => '',
            'MEMBER_ID' => placeholder_numeric_id(),
        ]), null, '', true);
    }
}
