<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_locations
 */

/**
 * Hook class.
 */
class Hook_addon_registry_core_locations
{
    /**
     * Get a list of file permissions to set.
     *
     * @param  boolean $runtime Whether to include wildcards represented runtime-created chmoddable files
     * @return array File permissions to set
     */
    public function get_chmod_array(bool $runtime = false) : array
    {
        return [];
    }

    /**
     * Get the current version of this addon (usually software major, software minor, addon build).
     * Put the comment "// addon_version_auto_update" to the right of the return if you want release tools to automatically update this according to software version and find_addon_effective_md5.
     *
     * @return SHORT_TEXT Version number
     */
    public function get_version() : string
    {
        return '11'; // addon_version_auto_update 506dee8dde230f60af3606afbc6ab762
    }

    /**
     * Get the minimum required version of the website software needed to use this addon.
     *
     * @return float Minimum required website software version
     */
    public function get_min_cms_version() : float
    {
        return 11.0;
    }

    /**
     * Get the maximum compatible version of the website software to use this addon.
     *
     * @return ?float Maximum compatible website software version (null: no maximum version currently)
     */
    public function get_max_cms_version() : ?float
    {
        return 11.9;
    }

    /**
     * Get the addon category.
     *
     * @return string The category
     */
    public function get_category() : string
    {
        return 'Information Display';
    }

    /**
     * Get the addon author.
     *
     * @return string The author
     */
    public function get_author() : string
    {
        return 'Chris Graham and Patrick Schmalstig';
    }

    /**
     * Find other authors.
     *
     * @return array A list of co-authors that should be attributed
     */
    public function get_copyright_attribution() : array
    {
        return [
            'SoKil',
        ];
    }

    /**
     * Get the addon licence (one-line summary only).
     *
     * @return string The licence
     */
    public function get_licence() : string
    {
        return 'The SoKil PHP ISO Codes is licenced under MIT';
    }

    /**
     * Get the description of the addon.
     *
     * @return string Description of the addon
     */
    public function get_description() : string
    {
        return "Core code managing geocoding and locations.";
    }

    /**
     * Get a list of tutorials that apply to this addon.
     *
     * @return array List of tutorials
     */
    public function get_applicable_tutorials() : array
    {
        return [
            'tut_parental_controls',
            'tut_statistics',
        ];
    }

    /**
     * Get a mapping of dependency types.
     *
     * @return array A structure specifying dependency information
     */
    public function get_dependencies() : array
    {
        return [
            'requires' => ['PHP gettext extension'],
            'recommends' => [],
            'conflicts_with' => [],
        ];
    }

    /**
     * Explicitly say which icon should be used.
     *
     * @return URLPATH Icon
     */
    public function get_default_icon() : string
    {
        return 'themes/default/images/icons/spare/world.svg';
    }

    /**
     * Get a list of files that belong to this addon.
     *
     * @return array List of files
     */
    public function get_file_list() : array
    {
        return [
            'data/geocode.php',
            'data/locations/.htaccess',
            'data/locations/IP_Country.txt',
            'data/locations/index.html',
            'sources/hooks/systems/addon_registry/core_locations.php',
            'sources/hooks/systems/geocoding/.htaccess',
            'sources/hooks/systems/geocoding/bing.php',
            'sources/hooks/systems/geocoding/google.php',
            'sources/hooks/systems/geocoding/index.html',
            'sources/hooks/systems/geocoding/mapquest.php',
            'sources/hooks/systems/snippets/regions.php',
            'sources/hooks/systems/tasks/install_geolocation_data.php',
            'sources/isocodes/.htaccess',
            'sources/isocodes/composer.json',
            'sources/isocodes/composer.lock',
            'sources/isocodes/index.html',
            'sources/isocodes/vendor/.htaccess',
            'sources/isocodes/vendor/autoload.php',
            'sources/isocodes/vendor/composer/.htaccess',
            'sources/isocodes/vendor/composer/ClassLoader.php',
            'sources/isocodes/vendor/composer/InstalledVersions.php',
            'sources/isocodes/vendor/composer/LICENSE',
            'sources/isocodes/vendor/composer/autoload_classmap.php',
            'sources/isocodes/vendor/composer/autoload_namespaces.php',
            'sources/isocodes/vendor/composer/autoload_psr4.php',
            'sources/isocodes/vendor/composer/autoload_real.php',
            'sources/isocodes/vendor/composer/autoload_static.php',
            'sources/isocodes/vendor/composer/index.html',
            'sources/isocodes/vendor/composer/installed.json',
            'sources/isocodes/vendor/composer/installed.php',
            'sources/isocodes/vendor/composer/platform_check.php',
            'sources/isocodes/vendor/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/LICENCE',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/README.md',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/bin/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/bin/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/bin/release.sh',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/composer.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/LICENSE',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_15924.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-1.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/AD.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/AE.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/AF.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/AG.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/AL.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/AM.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/AO.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/AR.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/AT.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/AU.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/AZ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BA.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BB.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BD.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BE.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BF.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BG.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BH.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BI.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BJ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BN.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BO.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BQ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BR.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BS.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BT.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BW.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BY.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/BZ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/CA.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/CD.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/CF.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/CG.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/CH.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/CI.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/CL.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/CM.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/CN.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/CO.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/CR.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/CU.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/CV.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/CY.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/CZ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/DE.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/DJ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/DK.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/DM.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/DO.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/DZ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/EC.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/EE.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/EG.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/ER.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/ES.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/ET.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/FI.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/FJ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/FM.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/FR.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/GA.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/GB.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/GD.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/GE.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/GH.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/GL.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/GM.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/GN.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/GQ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/GR.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/GT.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/GW.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/GY.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/HN.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/HR.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/HT.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/HU.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/ID.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/IE.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/IL.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/IN.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/IQ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/IR.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/IS.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/IT.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/JM.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/JO.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/JP.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/KE.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/KG.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/KH.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/KI.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/KM.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/KN.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/KP.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/KR.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/KW.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/KZ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/LA.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/LB.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/LC.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/LI.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/LK.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/LR.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/LS.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/LT.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/LU.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/LV.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/LY.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MA.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MC.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MD.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/ME.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MG.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MH.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MK.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/ML.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MM.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MN.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MR.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MT.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MU.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MV.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MW.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MX.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MY.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/MZ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/NA.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/NE.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/NG.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/NI.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/NL.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/NO.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/NP.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/NR.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/NZ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/OM.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/PA.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/PE.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/PG.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/PH.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/PK.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/PL.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/PS.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/PT.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/PW.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/PY.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/QA.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/RO.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/RS.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/RU.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/RW.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SA.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SB.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SC.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SD.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SE.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SG.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SH.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SI.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SK.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SL.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SM.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SN.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SO.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SR.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SS.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/ST.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SV.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SY.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/SZ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/TD.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/TG.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/TH.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/TJ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/TL.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/TM.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/TN.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/TO.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/TR.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/TT.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/TV.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/TW.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/TZ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/UA.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/UG.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/UM.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/US.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/UY.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/UZ.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/VC.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/VE.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/VN.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/VU.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/WF.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/WS.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/YE.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/ZA.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/ZM.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/ZW.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-2/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_3166-3.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_4217.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-2.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/a.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/b.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/c.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/d.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/e.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/f.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/g.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/h.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/i.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/j.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/k.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/l.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/m.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/n.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/o.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/p.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/q.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/r.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/s.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/t.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/u.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/v.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/w.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/x.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/y.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha2/z.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/aa.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ab.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ac.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ad.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ae.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/af.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ag.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ah.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ai.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/aj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ak.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/al.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/am.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/an.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ao.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ap.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/aq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ar.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/as.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/at.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/au.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/av.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/aw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ax.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ay.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/az.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ba.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bd.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/be.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bf.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bi.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bo.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/br.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bs.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bt.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bx.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/by.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/bz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ca.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cd.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ce.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cf.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ch.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ci.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ck.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/co.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cs.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ct.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cy.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/cz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/da.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/db.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dd.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/de.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/di.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/do.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ds.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dt.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/du.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dy.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/dz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ea.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/eb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ec.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ee.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ef.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/eg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/eh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ei.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ej.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ek.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/el.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/em.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/en.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/eo.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ep.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/er.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/es.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/et.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/eu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ev.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ew.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ex.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ey.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ez.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fa.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fe.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ff.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fi.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fo.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fs.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/fw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ga.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gd.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ge.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gf.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gi.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/go.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gs.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gt.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gx.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gy.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/gz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ha.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hd.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/he.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hi.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ho.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hs.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ht.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/hy.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ia.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ib.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ic.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/id.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/if.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ig.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ih.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ii.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ij.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ik.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/il.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/im.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/in.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/io.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ip.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/iq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ir.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/is.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/it.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/iu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/iv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/iw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ix.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/iy.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/iz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ja.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jd.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/je.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ji.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jo.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/js.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ju.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/jy.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ka.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kd.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ke.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kf.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ki.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/km.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ko.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ks.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kt.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ku.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kx.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ky.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/kz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/la.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ld.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/le.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lf.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/li.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ll.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ln.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lo.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ls.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lt.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lx.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ly.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/lz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ma.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/md.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/me.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mf.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mi.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ml.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mo.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ms.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mt.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mx.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/my.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/mz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/na.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nd.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ne.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nf.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ng.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ni.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/no.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/np.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ns.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nt.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nx.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ny.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/nz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/oa.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ob.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/oc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/od.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/of.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/og.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/oh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/oi.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/oj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ok.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ol.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/om.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/on.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/oo.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/op.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/or.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/os.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ot.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ou.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ov.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ow.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/oy.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/oz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pa.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pd.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pe.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pf.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ph.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pi.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/po.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ps.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pt.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/px.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/py.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/pz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/qu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/qv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/qw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/qx.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/qy.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ra.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rd.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/re.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ri.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ro.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rs.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rt.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ru.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rx.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ry.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/rz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sa.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sd.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/se.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sf.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/si.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/so.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ss.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/st.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/su.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sx.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sy.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/sz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ta.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/td.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/te.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tf.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/th.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ti.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/to.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ts.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tt.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tx.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ty.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/tz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ua.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ub.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ud.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ue.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/uf.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ug.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/uh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ui.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/uj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/uk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ul.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/um.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/un.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/uo.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/up.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ur.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/us.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ut.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/uu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/uv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/uw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/uy.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/uz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/va.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/vb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ve.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/vg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/vi.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/vk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/vl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/vm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/vn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/vo.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/vr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/vs.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/vt.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/vu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/vw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wa.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wd.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/we.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wf.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wi.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wo.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ws.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wt.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ww.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wx.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/wy.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xa.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xd.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xe.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xf.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xi.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xj.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xo.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xs.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xt.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xx.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xy.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/xz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ya.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yd.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ye.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yi.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ym.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yo.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ys.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yt.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yv.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yx.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yy.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/yz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/za.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zb.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zc.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zd.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/ze.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zg.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zh.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zi.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zk.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zl.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zm.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zn.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zo.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zp.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zq.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zr.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zs.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zt.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zu.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zw.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zx.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zy.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-3/alpha3/zz.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/databases/iso_639-5.json',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes-db-only/phpunit.xml.dist',
            'sources/isocodes/vendor/sokil/php-isocodes/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes/CHANGELOG.md',
            'sources/isocodes/vendor/sokil/php-isocodes/CONTRIBUTING.md',
            'sources/isocodes/vendor/sokil/php-isocodes/LICENSE',
            'sources/isocodes/vendor/sokil/php-isocodes/README.md',
            'sources/isocodes/vendor/sokil/php-isocodes/bin/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes/bin/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes/bin/iso_3166-2_split.php',
            'sources/isocodes/vendor/sokil/php-isocodes/bin/iso_639-3_split.php',
            'sources/isocodes/vendor/sokil/php-isocodes/bin/update_iso_codes_db.sh',
            'sources/isocodes/vendor/sokil/php-isocodes/composer.json',
            'sources/isocodes/vendor/sokil/php-isocodes/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes/phpcs.xml.dist',
            'sources/isocodes/vendor/sokil/php-isocodes/phpunit.xml.dist',
            'sources/isocodes/vendor/sokil/php-isocodes/psalm.xml',
            'sources/isocodes/vendor/sokil/php-isocodes/src/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes/src/AbstractDatabase.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/AbstractNotPartitionedDatabase.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/AbstractPartitionedDatabase.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Countries.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Countries/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Countries/Country.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Countries/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Currencies.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Currencies/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Currencies/Currency.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Currencies/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/HistoricCountries.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/HistoricCountries/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/HistoricCountries/Country.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/HistoricCountries/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Languages.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Languages/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Languages/Language.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Languages/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/LanguagesInterface.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/LanguagesPartitioned.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Scripts.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Scripts/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Scripts/Script.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Scripts/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Subdivisions.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Subdivisions/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Subdivisions/Subdivision.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/Subdivisions/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/SubdivisionsInterface.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/SubdivisionsPartitioned.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/Database/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes/src/IsoCodesFactory.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/TranslationDriver/.htaccess',
            'sources/isocodes/vendor/sokil/php-isocodes/src/TranslationDriver/DummyDriver.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/TranslationDriver/GettextExtensionDriver.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/TranslationDriver/SymfonyTranslationDriver.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/TranslationDriver/TranslationDriverInterface.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/TranslationDriver/TranslatorInterface.php',
            'sources/isocodes/vendor/sokil/php-isocodes/src/TranslationDriver/index.html',
            'sources/isocodes/vendor/sokil/php-isocodes/src/index.html',
            'sources/locations.php',
            'sources/locations_cpfs.php',
            'sources/locations_geocoding.php',
        ];
    }

    /**
     * Install the addon.
     *
     * @param  ?float $upgrade_major_minor From what major/minor version we are upgrading (null: new install)
     * @param  ?integer $upgrade_patch From what patch version of $upgrade_major_minor we are upgrading (null: new install)
     */
    public function install(?float $upgrade_major_minor = null, ?int $upgrade_patch = null)
    {
        if (($upgrade_major_minor !== null) || ($upgrade_patch !== null)) {
            // Queue the update of geolocation data (installer queues this for new installs)
            require_lang('locations');
            require_code('crypt');
            $secure_ref = get_secure_random_string();
            $GLOBALS['SITE_DB']->query_insert('task_queue', [
                't_title' => do_lang('INSTALL_GEOLOCATION_DATA'),
                't_hook' => 'install_geolocation_data',
                't_args' => serialize([]),
                't_member_id' => $GLOBALS['FORUM_DRIVER']->get_guest_id(),
                't_secure_ref' => $secure_ref, // Used like a temporary password to initiate the task
                't_send_notification' => 0,
                't_locked' => 0,
                't_add_time' => time(),
            ], true);
        }
    }
}
