<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_privacy
 */

/**
 * Hook class.
 */
class Hook_config_telemetry_may_feature
{
    /**
     * Gets the details relating to the config option.
     *
     * @return array The details
     */
    public function get_details() : array
    {
        return [
            'human_name' => 'CONFIG_TELEMETRY_MAY_FEATURE',
            'type' => 'tick',
            'category' => 'PRIVACY',
            'group' => 'GENERAL',
            'explanation' => 'CONFIG_OPTION_telemetry_may_feature',
            'shared_hosting_restricted' => '1',
            'list_options' => '',
            'order_in_category_group' => 2,
            'required' => true,
            'public' => false,
            'addon' => 'core_privacy',
        ];
    }

    /**
     * Gets the default value for the config option.
     *
     * @return ?string The default value (null: option is disabled)
     */
    public function get_default() : ?string
    {
        return '0';
    }

    /**
     * Code to run after the option is saved, if the value was changed or we are not formally setting it.
     *
     * @param  string $new_value The new value
     */
    public function postsave_handler(string $new_value)
    {
        // We need to update this setting with the homesite
        require_code('telemetry');
        $success = register_site_telemetry();
        if ($success === false) {
            require_lang('privacy');
            attach_message(do_lang_tempcode('TELEMETRY_FAILED_TO_REGISTER', escape_html(get_brand_base_url())), 'warn', false, true);
        }
    }
}
