<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    securitylogging
 */

/**
 * Hook class.
 */
class Hook_realtime_rain_security
{
    /**
     * Run function for realtime-rain hooks.
     *
     * @param  TIME $from Start of time range
     * @param  TIME $to End of time range
     * @return array A list of template parameter sets for rendering a 'drop'
     */
    public function run(int $from, int $to) : array
    {
        if (!addon_installed('securitylogging')) {
            return [];
        }

        $drops = [];

        if (has_actual_page_access(get_member(), 'admin_security')) {
            require_lang('security');

            // Hack-attacks
            $rows = $GLOBALS['SITE_DB']->query('SELECT id,reason,ip,date_and_time,risk_score,silent_to_staff_log AS timestamp,member_id FROM ' . $GLOBALS['SITE_DB']->get_table_prefix() . 'hackattack WHERE silent_to_staff_log<>1 AND risk_score>0 AND date_and_time BETWEEN ' . strval($from) . ' AND ' . strval($to));

            foreach ($rows as $row) {
                $timestamp = $row['timestamp'];
                $member_id = $row['member_id'];
                $risk_score = $row['risk_score'];

                $drops[] = rain_get_special_icons($row['ip'], $timestamp) + [
                    'TYPE' => 'security',
                    'FROM_MEMBER_ID' => strval($member_id),
                    'TO_MEMBER_ID' => null,
                    'TITLE' => rain_truncate_for_title(do_lang('HACKER_DETECTED', do_lang($row['reason']))),
                    'IMAGE' => is_guest($member_id) ? rain_get_country_image($row['ip']) : $GLOBALS['FORUM_DRIVER']->get_member_avatar_url($member_id),
                    'TIMESTAMP' => strval($timestamp),
                    'RELATIVE_TIMESTAMP' => strval($timestamp - $from),
                    'TICKER_TEXT' => null,
                    'URL' => build_url(['page' => 'admin_security', 'type' => 'view', 'id' => $row['id']], get_module_zone('admin_security')),
                    'IS_POSITIVE' => false,
                    'IS_NEGATIVE' => ($risk_score >= 5),

                    // These are for showing connections between drops. They are not discriminated, it's just three slots to give an ID code that may be seen as a commonality with other drops.
                    'FROM_ID' => 'member_' . strval($member_id),
                    'TO_ID' => null,
                    'GROUP_ID' => 'hack_type_' . $row['reason'],
                ];
            }

            // Failed logins
            $rows = $GLOBALS['SITE_DB']->query('SELECT id,ip,date_and_time,failed_account FROM ' . $GLOBALS['SITE_DB']->get_table_prefix() . 'failedlogins WHERE date_and_time BETWEEN ' . strval($from) . ' AND ' . strval($to));

            foreach ($rows as $row) {
                $timestamp = $row['date_and_time'];
                $member_id = $row['failed_account'];

                $drops[] = rain_get_special_icons($row['ip'], $timestamp) + [
                    'TYPE' => 'failedlogin',
                    'FROM_MEMBER_ID' => null,
                    'TO_MEMBER_ID' => null,
                    'TITLE' => rain_truncate_for_title(do_lang('FAILED_LOGIN', comcode_escape($member_id))),
                    'IMAGE' => rain_get_country_image($row['ip']),
                    'TIMESTAMP' => strval($timestamp),
                    'RELATIVE_TIMESTAMP' => strval($timestamp - $from),
                    'TICKER_TEXT' => null,
                    'URL' => build_url(['page' => 'admin_security'], get_module_zone('admin_security')),
                    'IS_POSITIVE' => false,
                    'IS_NEGATIVE' => true,

                    // These are for showing connections between drops. They are not discriminated, it's just three slots to give an ID code that may be seen as a commonality with other drops.
                    'FROM_ID' => null,
                    'TO_ID' => null,
                    'GROUP_ID' => null,
                ];
            }
        }

        return $drops;
    }
}
