<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_locations
 */

/**
 * Hook class.
 */
class Hook_snippet_regions
{
    /**
     * Run function for snippet hooks. Generates HTML to insert into a page using AJAX.
     *
     * @return Tempcode The snippet
     */
    public function run() : object
    {
        require_code('locations');
        require_lang('locations');

        $country = post_param_string('country', '');

        $ret = ['options' => [['value' => '', 'text' => do_lang('CHOOSE_REGION')]]];

        if ($country == '') {
            $ret['options'] = [['value' => '', 'text' => do_lang('REGION_MUST_CHOOSE_COUNTRY')]];
            return make_string_tempcode(json_encode($ret));
        }

        $regions = find_regions_by_country($country);

        foreach ($regions as $region) {
            $ret['options'][] = ['value' => $region->getCode(), 'text' => $region->getLocalName()];
        }

        // Not all countries have regions
        if (count($regions) == 0) {
            $ret['options'][] = ['value' => $country, 'text' => do_lang('_ALL')];
        }

        return make_string_tempcode(json_encode($ret));
    }
}
